# Django Roadies

[![CircleCI](https://circleci.com/gh/anthonyalmarza/django-roadies.svg?style=svg)](https://circleci.com/gh/anthonyalmarza/django-roadies)
[![codecov](https://codecov.io/gh/anthonyalmarza/django-roadies/branch/master/graph/badge.svg)](https://codecov.io/gh/anthonyalmarza/django-roadies)

Suite of django specific utilities/helpers.

## Overview

Yet another django toolset to help with a range of django stuff... e.g. tests for abstract models, on_commit hooks, etc.
The genesis of this project is aimed towards supporting django by making available common project-agnostic tools.

## Installation

`pip install django-roadies`

## Usage

TDB

## Development

Ensure docker is installed. Instructions on installing docker can be found [here](https://docs.docker.com/install/).
Once docker is installed build the docker image by running the following script:

```bash
./bin/local/build
```

then, running tests is as simple as:

```bash
./bin/local/test
```
